@@ -13,7 +13,7 @@ import logging
 #     from ..opentele import *
 
 
-class MapData(BaseObject):
+class MapData(BaseObject):  # nocov
     def __init__(self, basePath: str) -> None:
 
         self.basePath = basePath
@@ -170,7 +170,6 @@ class MapData(BaseObject):
                 #     ? legacyBackgroundKeyNight
                 #     : legacyBackgroundKeyDay);
                 map.stream >> legacyBackgroundKeyDay
-                pass
 
             elif keyType == lskType.lskBackgroundOld:
                 legacyBackgroundKeyDay = map.stream.readUInt64()
@@ -353,7 +352,7 @@ class MapData(BaseObject):
         return mapData
 
 
-class StorageAccount(BaseObject):
+class StorageAccount(BaseObject):  # nocov
     """
     Storage account for reading and writing to tdata
     """
@@ -443,7 +442,10 @@ class StorageAccount(BaseObject):
 
         self.__localKey = localKey
         self.readMapWith(localKey)
-        return self.readMtpConfig()
+
+        return (
+            self.__config if self.owner.owner.kPerformanceMode else self.readMtpConfig()
+        )
 
     def readMtpData(self):
         # Intended for internal usage only
@@ -568,7 +570,10 @@ class StorageAccount(BaseObject):
             baseGlobalPath, td.Storage.ToFilePart(dataNameKey)
         )
         self.writeMap(basePath)
-        self.writeMtpConfig(basePath)
+
+        if not self.owner.owner.kPerformanceMode:
+            self.writeMtpConfig(basePath)
+
         self.writeMtpData(baseGlobalPath, dataNameKey)
 
 
@@ -990,36 +995,33 @@ class Account(BaseObject):
             LoginFlagInvalid("LoginFlag invalid"),
         )
 
-        if not telethonClient.is_connected():
-            try:
-                await telethonClient.connect()
-            except OSError as e:
-                raise TelethonUnauthorized(
-                    "Could not connect telethon client to the server, please try to connect manually"
-                ) from e
-
-        Expects(
-            await telethonClient.is_user_authorized(),
-            exception=TelethonUnauthorized(
-                "Telethon client is unauthorized, it need to be authorized first"
-            ),
-        )
-
         if flag == CreateNewSession:
+            if not telethonClient.is_connected():
+                try:
+                    await telethonClient.connect()
+                except OSError as e:
+                    raise TelethonUnauthorized(
+                        "Could not connect telethon client to the server, please try to connect manually"
+                    ) from e
+
+                Expects(
+                    await telethonClient.is_user_authorized(),
+                    exception=TelethonUnauthorized(
+                        "Telethon client is unauthorized, it need to be authorized first"
+                    ),
+                )
+
             copy = await telethonClient.QRLoginToNewClient(api=api, password=password)
+            await copy.get_me()
         else:
             copy = telethonClient
 
         ss = copy.session
         authKey = ss.auth_key.key
         dcId = DcId(ss.dc_id)
-        userId = copy._self_id
+        userId = copy.UserId
         authKey = td.AuthKey(authKey, td.AuthKeyType.ReadFromFile, dcId)
 
-        if userId == None:
-            await copy.get_me()
-            userId = copy._self_id
-
         newAccount = None
 
         if owner != None:
