@@ -1,11 +1,18 @@
-
 from ..exception import *
 from ..utils import *
 from ..api import APIData, API, LoginFlag, CreateNewSession, UseCurrentSession
 from .. import td
 
 from typing import Union, Callable, TypeVar, Type, List, Dict, Any, TYPE_CHECKING
-from ctypes import sizeof, c_int32 as int32, c_int64 as int64, c_uint32 as uint32, c_uint64 as uint64, c_short as short, c_ushort as ushort
+from ctypes import (
+    sizeof,
+    c_int32 as int32,
+    c_int64 as int64,
+    c_uint32 as uint32,
+    c_uint64 as uint64,
+    c_short as short,
+    c_ushort as ushort,
+)
 
 import telethon
 from telethon.sessions import StringSession
@@ -21,4 +28,3 @@ from telethon.sessions.sqlite import SQLiteSession
 from telethon.sessions.memory import MemorySession
 
 import asyncio
-
